@@ -1,3 +1,5 @@
+from pathlib import Path
+
 from django.db import IntegrityError
 import pytest
 from rgd.datastore import datastore, registry
@@ -37,6 +39,21 @@ def test_create_url():
     assert model.name
 
 
+@pytest.mark.django_db(transaction=True)
+def test_create_url_local_file():
+    path = Path('/opt/django-project/README.md')
+    path.parent.mkdir(parents=True, exist_ok=True)
+    path.touch()
+    model = ChecksumFile()
+    model.type = FileSourceType.URL
+    model.url = f'file://{path}'
+    model.save()
+    model.post_save_job()
+    model.refresh_from_db()
+    assert model.checksum
+    assert model.name
+
+
 @pytest.mark.django_db(transaction=True)
 def test_constraint_mismatch(file_path):
     with pytest.raises(IntegrityError):
